@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from time import sleep
+
 from .baseapi import BaseAPI
 
 
@@ -13,6 +15,7 @@ class Action(BaseAPI):
         self.resource_id = None
         self.resource_type = None
         self.region = None
+        self.region_slug = None
         # Custom, not provided by the json object.
         self.droplet_id = None
 
@@ -48,5 +51,20 @@ class Action(BaseAPI):
             for attr in action.keys():
                 setattr(self, attr, action[attr])
 
+    def wait(self, update_every_seconds=1):
+        """
+            Wait until the action is marked as completed or with an error.
+            It will return True in case of success, otherwise False.
+
+            Optional Args:
+                update_every_seconds - int : number of seconds to wait before
+                    checking if the action is completed.
+        """
+        while self.status == u'in-progress':
+            sleep(update_every_seconds)
+            self.load()
+
+        return self.status == u'completed'
+
     def __str__(self):
         return "%s %s [%s]" % (self.id, self.type, self.status)
