@@ -22,7 +22,7 @@ class BadSSHKeyFormat(DropletError):
 
 
 class Droplet(BaseAPI):
-    """"Droplet managment
+    """"Droplet management
 
     Attributes accepted at creation time:
         name: str - name
@@ -162,7 +162,7 @@ class Droplet(BaseAPI):
             return action
         else:
             action = action[u'action']
-            return_action = Action()
+            return_action = Action(token=self.token)
             # Loading attributes
             for attr in action.keys():
                 setattr(return_action, attr, action[attr])
@@ -257,7 +257,7 @@ class Droplet(BaseAPI):
             return_dict
         )
 
-    def take_snapshot(self, snapshot_name, return_dict=True):
+    def take_snapshot(self, snapshot_name, return_dict=True, power_off=False):
         """Take a snapshot!
 
         Args:
@@ -266,9 +266,17 @@ class Droplet(BaseAPI):
         Optional Args:
             return_dict - bool : Return a dict when True (default),
                 otherwise return an Action.
+            power_off - bool : Before taking the snapshot the droplet will be
+                turned off with another API call. It will wait until the
+                droplet will be powered off.
 
         Returns dict or Action
         """
+        if power_off is True and self.status != "off":
+            action = self.power_off(return_dict=False)
+            action.wait()
+            self.load()
+
         return self._perform_action(
             {"type": "snapshot", "name": snapshot_name},
             return_dict
@@ -368,7 +376,10 @@ class Droplet(BaseAPI):
 
            Returns dict or Action
         """
-        return self._perform_action({'type': 'enable_private_networking'}, return_dict)
+        return self._perform_action(
+            {'type': 'enable_private_networking'},
+            return_dict
+        )
 
     def enable_ipv6(self, return_dict=True):
         """
@@ -410,7 +421,7 @@ class Droplet(BaseAPI):
         """
         ssh_keys_id = list()
         for ssh_key in self.ssh_keys:
-            if type(ssh_key) in [int, type(2**64)]:
+            if type(ssh_key) in [int, type(2 ** 64)]:
                 ssh_keys_id.append(int(ssh_key))
 
             elif type(ssh_key) == SSHKey:
@@ -540,17 +551,17 @@ class Droplet(BaseAPI):
         kernels = list()
         data = self.get_data("droplets/%s/kernels/" % self.id)
         while True:
-                for jsond in data[u'kernels']:
-                    kernel = Kernel(**jsond)
-                    kernel.token = self.token
-                    kernels.append(kernel)
-                try:
-                    url = data[u'links'][u'pages'].get(u'next')
-                    if not url:
-                            break
-                    data = self.get_data(url)
-                except KeyError:  # No links.
-                    break
+            for jsond in data[u'kernels']:
+                kernel = Kernel(**jsond)
+                kernel.token = self.token
+                kernels.append(kernel)
+            try:
+                url = data[u'links'][u'pages'].get(u'next')
+                if not url:
+                        break
+                data = self.get_data(url)
+            except KeyError:  # No links.
+                break
 
         return kernels
 
